Documentation
¶
Overview ¶
Package agents provides the Architect Agent implementation using the OODA Chassis SDK with Dual Memory architecture.
Index ¶
- type ArchitectAgent
- func (a *ArchitectAgent) ClearSession(ctx context.Context) error
- func (a *ArchitectAgent) GetAuditTrail() string
- func (a *ArchitectAgent) GetSessionState(ctx context.Context) (map[string]interface{}, error)
- func (a *ArchitectAgent) Run(ctx context.Context, input core.Envelope) (*core.WorkflowResult, error)
- func (a *ArchitectAgent) RunOODA(ctx context.Context, input string) (*ooda.CognitiveFrame, error)
- func (a *ArchitectAgent) SetKnowledgeStore(store ports.KnowledgeStore)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ArchitectAgent ¶
type ArchitectAgent struct {
// contains filtered or unexported fields
}
ArchitectAgent implements the Architect Agent using OODA Chassis
func NewArchitectAgent ¶
func NewArchitectAgent(ctx context.Context, engine *multiagent.AgentSystem, workflowID string) (*ArchitectAgent, error)
NewArchitectAgent creates a new Architect Agent
func (*ArchitectAgent) ClearSession ¶
func (a *ArchitectAgent) ClearSession(ctx context.Context) error
ClearSession clears the session state
func (*ArchitectAgent) GetAuditTrail ¶
func (a *ArchitectAgent) GetAuditTrail() string
GetAuditTrail returns the audit trail from the last run
func (*ArchitectAgent) GetSessionState ¶
func (a *ArchitectAgent) GetSessionState(ctx context.Context) (map[string]interface{}, error)
GetSessionState returns the current session state from TransientStore
func (*ArchitectAgent) Run ¶
func (a *ArchitectAgent) Run(ctx context.Context, input core.Envelope) (*core.WorkflowResult, error)
Run executes the Architect Agent workflow
func (*ArchitectAgent) RunOODA ¶
func (a *ArchitectAgent) RunOODA(ctx context.Context, input string) (*ooda.CognitiveFrame, error)
RunOODA executes a single OODA cycle (for step-by-step execution)
func (*ArchitectAgent) SetKnowledgeStore ¶
func (a *ArchitectAgent) SetKnowledgeStore(store ports.KnowledgeStore)
SetKnowledgeStore sets the knowledge store (MEB adapter)
Click to show internal directories.
Click to hide internal directories.